@@ -101,17 +101,20 @@ ADB = None
 WINDOWS = False
 LINUX = False
 MACOS = False
+FREEBSD = False
 if os.name == 'nt':
   WINDOWS = True
   import winreg
 elif platform.system() == 'Linux':
   LINUX = True
+elif platform.system() == 'FreeBSD':
+  FREEBSD = True
 elif platform.mac_ver()[0] != '':
   MACOS = True
   import plistlib
 
 # If you are running on an OS that is not any of these, must add explicit support for it.
-if not WINDOWS and not LINUX and not MACOS:
+if not WINDOWS and not LINUX and not MACOS and not FREEBSD:
   raise Exception("Unknown OS!")
 
 
@@ -389,14 +392,15 @@ def kill_browser_process():
 
   if processname_killed_atexit:
     if emrun_options.android:
-      logv("Terminating Android app '" + processname_killed_atexit + "'.")
+      logv(f"Terminating Android app '{processname_killed_atexit}'.")
       subprocess.call([ADB, 'shell', 'am', 'force-stop', processname_killed_atexit])
     else:
-      logv("Terminating all processes that have string '" + processname_killed_atexit + "' in their name.")
+      logv(f"Terminating all processes that have string '{processname_killed_atexit}' in their name.")
       if WINDOWS:
-        process_image = processname_killed_atexit if '.exe' in processname_killed_atexit else (processname_killed_atexit + '.exe')
-        process = subprocess.Popen(['taskkill', '/F', '/IM', process_image, '/T'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        process.communicate()
+        process_image = processname_killed_atexit
+        if not process_image.endswith('.exe'):
+          process_image += '.exe'
+        subprocess.call(['taskkill', '/F', '/IM', process_image, '/T'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
       else:
         try:
           subprocess.call(['pkill', processname_killed_atexit])
@@ -414,7 +418,7 @@ def kill_browser_process():
 
 # Heuristic that attempts to search for the browser process IDs that emrun spawned.
 # This depends on the assumption that no other browser process IDs have been spawned
-# during the short time perioed between the time that emrun started, and the browser
+# during the short time period between the time that emrun started, and the browser
 # process navigated to the page.
 # This heuristic is needed because all modern browsers are multiprocess systems -
 # starting a browser process from command line generally launches just a "stub" spawner
@@ -442,7 +446,7 @@ def detect_browser_processes():
     logv('Was unable to detect the browser process that was spawned by emrun. This may occur if the target page was opened in a tab on a browser process that already existed before emrun started up.')
 
 
-# Our custom HTTP web server that will server the target page to run via .html.
+# Our custom HTTP web server that will serve the target page to run via .html.
 # This is used so that we can load the page via a http:// URL instead of a
 # file:// URL, since those wouldn't work too well unless user allowed XHR
 # without CORS rules.  Also, the target page will route its stdout and stderr
@@ -476,7 +480,7 @@ class HTTPWebServer(socketserver.ThreadingMixIn, HTTPServer):
         if len(self.http_message_queue) > 16:
           self.print_next_message()
 
-  # If it's been too long since we we got a message, prints out the oldest
+  # If it's been too long since we got a message, prints out the oldest
   # queued message, ignoring the proper order.  This ensures that if any
   # messages are actually lost, that the message queue will be orderly flushed.
   def print_timed_out_messages(self):
@@ -749,7 +753,7 @@ class HTTPHandler(SimpleHTTPRequestHandler):
     self.wfile.write(b'OK')
 
 
-# Returns stdout by running command with universal_newlines=True
+# Returns stdout by running command with text=True
 def check_output(cmd, *args, **kwargs):
   return subprocess.run(cmd, text=True, stdout=subprocess.PIPE, check=True, *args, **kwargs).stdout
 
@@ -784,6 +788,11 @@ def get_cpu_info():
       sockets = int(re.search(r'Socket\(s\): (.*)', lscpu).group(1).strip())
       physical_cores = sockets * int(re.search(r'Core\(s\) per socket: (.*)', lscpu).group(1).strip())
       logical_cores = physical_cores * int(re.search(r'Thread\(s\) per core: (.*)', lscpu).group(1).strip())
+    elif FREEBSD:
+      cpu_name = check_output(['sysctl', '-n', 'hw.model']).strip()
+      physical_cores = int(check_output(['sysctl', '-n', 'hw.ncpu']).strip())
+      logical_cores = physical_cores
+      frequency = int(check_output(['sysctl', '-n', 'hw.clockrate']).strip())
   except Exception as e:
     import traceback
     loge(traceback.format_exc())
@@ -831,12 +840,12 @@ def win_get_gpu_info():
       VideoCardString = winreg.QueryValueEx(hVideoReg, '\\Device\\Video' + str(i))[0]
       # Get Rid of Registry/Machine from the string
       VideoCardStringSplit = VideoCardString.split('\\')
-      ClearnVideoCardString = "\\".join(VideoCardStringSplit[3:])
+      CleanVideoCardString = "\\".join(VideoCardStringSplit[3:])
       # Go up one level for detailed
       # VideoCardStringRoot = "\\".join(VideoCardStringSplit[3:len(VideoCardStringSplit)-1])
 
       # Get the graphics card information
-      hVideoCardReg = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, ClearnVideoCardString)
+      hVideoCardReg = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, CleanVideoCardString)
       try:
         VideoCardDescription = winreg.QueryValueEx(hVideoCardReg, 'Device Description')[0]
       except WindowsError:
@@ -1004,7 +1013,7 @@ def win_get_file_properties(fname):
   props = {'FixedFileInfo': None, 'StringFileInfo': None, 'FileVersion': None}
 
   import win32api
-  # backslash as parm returns dictionary of numeric info corresponding to VS_FIXEDFILEINFO struct
+  # backslash as param returns dictionary of numeric info corresponding to VS_FIXEDFILEINFO struct
   fixedInfo = win32api.GetFileVersionInfo(fname, '\\')
   props['FixedFileInfo'] = fixedInfo
   props['FileVersion'] = "%d.%d.%d.%d" % (fixedInfo['FileVersionMS'] / 65536,
@@ -1016,7 +1025,7 @@ def win_get_file_properties(fname):
   # pairs that can be used to retrieve string info. We are using only the first pair.
   lang, codepage = win32api.GetFileVersionInfo(fname, '\\VarFileInfo\\Translation')[0]
 
-  # any other must be of the form \StringfileInfo\%04X%04X\parm_name, middle
+  # any other must be of the form \StringfileInfo\%04X%04X\param_name, middle
   # two are language/codepage pair returned from above
 
   strInfo = {}
@@ -1119,6 +1128,8 @@ def get_system_memory():
       return win32api.GlobalMemoryStatusEx()['TotalPhys']
     elif MACOS:
       return int(check_output(['sysctl', '-n', 'hw.memsize']).strip())
+    elif FREEBSD:
+      return int(check_output(['sysctl', '-n', 'hw.physmem']).strip())
   except Exception:
     return -1
 
@@ -1133,19 +1144,15 @@ def which(program):
     if is_exe(program):
       return program
   else:
-    for path in os.environ["PATH"].split(os.pathsep):
+    exe_suffixes = ['']
+    if WINDOWS and '.' not in fname:
+      exe_suffixes = ['.exe', '.cmd', '.bat']
+    for path in os.environ['PATH'].split(os.pathsep):
       path = path.strip('"')
       exe_file = os.path.join(path, program)
-      if is_exe(exe_file):
-        return exe_file
-
-      if WINDOWS and '.' not in fname:
-        if is_exe(exe_file + '.exe'):
-          return exe_file + '.exe'
-        if is_exe(exe_file + '.cmd'):
-          return exe_file + '.cmd'
-        if is_exe(exe_file + '.bat'):
-          return exe_file + '.bat'
+      for ext in exe_suffixes:
+        if is_exe(exe_file + ext):
+          return exe_file + ext
 
   return None
 
@@ -1225,7 +1232,7 @@ def find_browser(name):
                             ('iexplore', os.path.join(program_files, 'Internet Explorer/iexplore.exe')),
                             ('opera', os.path.join(program_files, 'Opera/launcher.exe'))]
 
-  elif LINUX:
+  elif LINUX or FREEBSD:
     browser_locations = [('firefox', os.path.expanduser('~/firefox/firefox')),
                          ('firefox_beta', os.path.expanduser('~/firefox_beta/firefox')),
                          ('firefox_aurora', os.path.expanduser('~/firefox_aurora/firefox')),
@@ -1350,12 +1357,12 @@ def subprocess_env():
 def remove_tree(d):
   os.chmod(d, stat.S_IWRITE)
   try:
-    def remove_readonly_and_try_again(func, path, _exc_info):
+    def remove_readonly_and_try_again(func, path, exc_info):
       if not (os.stat(path).st_mode & stat.S_IWRITE):
         os.chmod(path, stat.S_IWRITE)
         func(path)
       else:
-        raise
+        raise exc_info[1]
     shutil.rmtree(d, onerror=remove_readonly_and_try_again)
   except Exception:
     pass
@@ -1557,7 +1564,7 @@ def parse_args(args):
 
   parser.add_argument('--json', action='store_true',
                       help='If specified, --system-info and --browser-info are '
-                           'outputted in JSON format.')
+                           'output in JSON format.')
 
   parser.add_argument('--safe-firefox-profile', action='store_true',
                       help='If true, the browser is launched into a new clean '
@@ -1576,7 +1583,7 @@ def parse_args(args):
   parser.add_argument('cmdlineparams', nargs='*')
 
   # Support legacy argument names with `_` in them (but don't
-  # advertize these in the --help message).
+  # advertise these in the --help message).
   for i, a in enumerate(args):
     if a == '--':
       break
@@ -1615,7 +1622,7 @@ def run(args):  # noqa: C901, PLR0912, PLR0915
   if not options.browser and not options.android:
     if WINDOWS:
       options.browser = 'start'
-    elif LINUX:
+    elif LINUX or FREEBSD:
       options.browser = which('xdg-open')
       if not options.browser:
         options.browser = 'firefox'
