@@ -540,27 +540,32 @@ var WasiLibrary = {
     return 0;
   },
 
-  fd_sync__async: true,
-  fd_sync: (fd) => {
 #if SYSCALLS_REQUIRE_FILESYSTEM
+  fd_sync__async: 'auto',
+  fd_sync: (fd) => {
     var stream = SYSCALLS.getStreamFromFD(fd);
     var rtn = stream.stream_ops?.fsync?.(stream);
-#if ASYNCIFY
-    var mount = stream.node.mount;
-    if (mount.type.syncfs) {
-      return Asyncify.handleSleep((wakeUp) => {
-        mount.type.syncfs(mount, false, (err) => wakeUp(err ? {{{ cDefs.EIO }}} : 0));
-      });
-    }
-#endif // ASYNCIFY
+#if ASYNCIFY || PTHREADS
+    return new Promise((resolve) => {
+      var mount = stream.node.mount;
+      if (mount?.type.syncfs) {
+        mount.type.syncfs(mount, false, (err) => resolve(err ? {{{ cDefs.EIO }}} : 0));
+      } else {
+        resolve(rtn);
+      }
+    });
+#else
     return rtn;
+#endif // ASYNCIFY || PTHREADS
+  },
 #else // SYSCALLS_REQUIRE_FILESYSTEM
+  fd_sync: (fd) => {
 #if ASSERTIONS
     abort('fd_sync called without SYSCALLS_REQUIRE_FILESYSTEM');
 #endif
     return {{{ cDefs.ENOSYS }}};
-#endif // SYSCALLS_REQUIRE_FILESYSTEM
   },
+#endif // SYSCALLS_REQUIRE_FILESYSTEM
 
   // random.h
 
@@ -571,7 +576,7 @@ var WasiLibrary = {
 #if ENVIRONMENT_MAY_BE_NODE && MIN_NODE_VERSION < 190000
     // This block is not needed on v19+ since crypto.getRandomValues is builtin
     if (ENVIRONMENT_IS_NODE) {
-      var nodeCrypto = require('crypto');
+      var nodeCrypto = require('node:crypto');
       return (view) => nodeCrypto.randomFillSync(view);
     }
 #endif // ENVIRONMENT_MAY_BE_NODE
