@@ -70,7 +70,7 @@ addToLibrary({
 
   _wasmfs_opfs_init_root_directory__deps: ['$wasmfsOPFSDirectoryHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_init_root_directory__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_init_root_directory: async function(ctx) {
+  _wasmfs_opfs_init_root_directory: async (ctx) => {
     // allocated.length starts off as 1 since 0 is a reserved handle
     if (wasmfsOPFSDirectoryHandles.allocated.length == 1) {
       // Closure compiler errors on this as it does not recognize the OPFS
@@ -89,7 +89,7 @@ addToLibrary({
   // corresponding to the error.
   $wasmfsOPFSGetOrCreateFile__deps: ['$wasmfsOPFSDirectoryHandles',
                                      '$wasmfsOPFSFileHandles'],
-  $wasmfsOPFSGetOrCreateFile: async function(parent, name, create) {
+  $wasmfsOPFSGetOrCreateFile: async (parent, name, create) => {
     let parentHandle = wasmfsOPFSDirectoryHandles.get(parent);
     let fileHandle;
     try {
@@ -113,7 +113,7 @@ addToLibrary({
   // it if it doesn't exist and `create` or otherwise return a negative error
   // code corresponding to the error.
   $wasmfsOPFSGetOrCreateDir__deps: ['$wasmfsOPFSDirectoryHandles'],
-  $wasmfsOPFSGetOrCreateDir: async function(parent, name, create) {
+  $wasmfsOPFSGetOrCreateDir: async (parent, name, create) => {
     let parentHandle = wasmfsOPFSDirectoryHandles.get(parent);
     let childHandle;
     try {
@@ -137,8 +137,7 @@ addToLibrary({
   _wasmfs_opfs_get_child__deps: ['$wasmfsOPFSGetOrCreateFile',
                                  '$wasmfsOPFSGetOrCreateDir', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_get_child__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_get_child:
-      async function(ctx, parent, namePtr, childTypePtr, childIDPtr) {
+  _wasmfs_opfs_get_child: async (ctx, parent, namePtr, childTypePtr, childIDPtr) => {
     let name = UTF8ToString(namePtr);
     let childType = 1;
     let childID = await wasmfsOPFSGetOrCreateFile(parent, name, false);
@@ -158,7 +157,7 @@ addToLibrary({
     '_wasmfs_opfs_record_entry',
   ],
   _wasmfs_opfs_get_entries__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_get_entries: async function(ctx, dirID, entriesPtr, errPtr) {
+  _wasmfs_opfs_get_entries: async (ctx, dirID, entriesPtr, errPtr) => {
     let dirHandle = wasmfsOPFSDirectoryHandles.get(dirID);
 
     // TODO: Use 'for await' once Acorn supports that.
@@ -183,7 +182,7 @@ addToLibrary({
 
   _wasmfs_opfs_insert_file__deps: ['$wasmfsOPFSGetOrCreateFile', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_insert_file__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_insert_file: async function(ctx, parent, namePtr, childIDPtr) {
+  _wasmfs_opfs_insert_file: async (ctx, parent, namePtr, childIDPtr) => {
     let name = UTF8ToString(namePtr);
     let childID = await wasmfsOPFSGetOrCreateFile(parent, name, true);
     {{{ makeSetValue('childIDPtr', 0, 'childID', 'i32') }}};
@@ -192,8 +191,7 @@ addToLibrary({
 
   _wasmfs_opfs_insert_directory__deps: ['$wasmfsOPFSGetOrCreateDir', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_insert_directory__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_insert_directory:
-      async function(ctx, parent, namePtr, childIDPtr) {
+  _wasmfs_opfs_insert_directory: async (ctx, parent, namePtr, childIDPtr) => {
     let name = UTF8ToString(namePtr);
     let childID = await wasmfsOPFSGetOrCreateDir(parent, name, true);
     {{{ makeSetValue('childIDPtr', 0, 'childID', 'i32') }}};
@@ -204,7 +202,7 @@ addToLibrary({
                                  '$wasmfsOPFSDirectoryHandles',
                                  '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_move_file__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_move_file: async function(ctx, fileID, newParentID, namePtr, errPtr) {
+  _wasmfs_opfs_move_file: async (ctx, fileID, newParentID, namePtr, errPtr) => {
     let name = UTF8ToString(namePtr);
     let fileHandle = wasmfsOPFSFileHandles.get(fileID);
     let newDirHandle = wasmfsOPFSDirectoryHandles.get(newParentID);
@@ -219,7 +217,7 @@ addToLibrary({
 
   _wasmfs_opfs_remove_child__deps: ['$wasmfsOPFSDirectoryHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_remove_child__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_remove_child: async function(ctx, dirID, namePtr, errPtr) {
+  _wasmfs_opfs_remove_child: async (ctx, dirID, namePtr, errPtr) => {
     let name = UTF8ToString(namePtr);
     let dirHandle = wasmfsOPFSDirectoryHandles.get(dirID);
     try {
@@ -248,7 +246,7 @@ addToLibrary({
 #endif
                                   ],
   _wasmfs_opfs_open_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_open_access: async function(ctx, fileID, accessIDPtr) {
+  _wasmfs_opfs_open_access: async (ctx, fileID, accessIDPtr) => {
     let fileHandle = wasmfsOPFSFileHandles.get(fileID);
     let accessID;
     try {
@@ -288,7 +286,7 @@ addToLibrary({
   _wasmfs_opfs_open_blob__deps: ['$wasmfsOPFSFileHandles',
                                  '$wasmfsOPFSBlobs', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_open_blob__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_open_blob: async function(ctx, fileID, blobIDPtr) {
+  _wasmfs_opfs_open_blob: async (ctx, fileID, blobIDPtr) => {
     let fileHandle = wasmfsOPFSFileHandles.get(fileID);
     let blobID;
     try {
@@ -310,7 +308,7 @@ addToLibrary({
 
   _wasmfs_opfs_close_access__deps: ['$wasmfsOPFSAccessHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_close_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_close_access: async function(ctx, accessID, errPtr) {
+  _wasmfs_opfs_close_access: async (ctx, accessID, errPtr) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     try {
       await accessHandle.close();
@@ -330,7 +328,7 @@ addToLibrary({
   _wasmfs_opfs_read_access__i53abi: true,
   _wasmfs_opfs_read_access__deps: ['$wasmfsOPFSAccessHandles'],
   _wasmfs_opfs_read_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_read_access: {{{ asyncIf(!PTHREADS) }}}function(accessID, bufPtr, len, pos) {
+  _wasmfs_opfs_read_access: {{{ asyncIf(!PTHREADS) }}}(accessID, bufPtr, len, pos) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     let data = HEAPU8.subarray(bufPtr, bufPtr + len);
     try {
@@ -349,7 +347,7 @@ addToLibrary({
   _wasmfs_opfs_read_blob__i53abi: true,
   _wasmfs_opfs_read_blob__deps: ['$wasmfsOPFSBlobs', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_read_blob__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_read_blob: async function(ctx, blobID, bufPtr, len, pos, nreadPtr) {
+  _wasmfs_opfs_read_blob: async (ctx, blobID, bufPtr, len, pos, nreadPtr) => {
     let blob = wasmfsOPFSBlobs.get(blobID);
     let slice = blob.slice(pos, pos + len);
     let nread = 0;
@@ -380,7 +378,7 @@ addToLibrary({
   _wasmfs_opfs_write_access__i53abi: true,
   _wasmfs_opfs_write_access__deps: ['$wasmfsOPFSAccessHandles'],
   _wasmfs_opfs_write_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_write_access: {{{ asyncIf(!PTHREADS) }}}function(accessID, bufPtr, len, pos) {
+  _wasmfs_opfs_write_access: {{{ asyncIf(!PTHREADS) }}}(accessID, bufPtr, len, pos) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     let data = HEAPU8.subarray(bufPtr, bufPtr + len);
     try {
@@ -398,7 +396,7 @@ addToLibrary({
 
   _wasmfs_opfs_get_size_access__deps: ['$wasmfsOPFSAccessHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_get_size_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_get_size_access: async function(ctx, accessID, sizePtr) {
+  _wasmfs_opfs_get_size_access: async (ctx, accessID, sizePtr) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     let size;
     try {
@@ -419,7 +417,7 @@ addToLibrary({
 
   _wasmfs_opfs_get_size_file__deps: ['$wasmfsOPFSFileHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_get_size_file__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_get_size_file: async function(ctx, fileID, sizePtr) {
+  _wasmfs_opfs_get_size_file: async (ctx, fileID, sizePtr) => {
     let fileHandle = wasmfsOPFSFileHandles.get(fileID);
     let size;
     try {
@@ -434,7 +432,7 @@ addToLibrary({
   _wasmfs_opfs_set_size_access__i53abi: true,
   _wasmfs_opfs_set_size_access__deps: ['$wasmfsOPFSAccessHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_set_size_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_set_size_access: async function(ctx, accessID, size, errPtr) {
+  _wasmfs_opfs_set_size_access: async (ctx, accessID, size, errPtr) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     try {
       await accessHandle.truncate(size);
@@ -448,7 +446,7 @@ addToLibrary({
   _wasmfs_opfs_set_size_file__i53abi: true,
   _wasmfs_opfs_set_size_file__deps: ['$wasmfsOPFSFileHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_set_size_file__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_set_size_file: async function(ctx, fileID, size, errPtr) {
+  _wasmfs_opfs_set_size_file: async (ctx, fileID, size, errPtr) => {
     let fileHandle = wasmfsOPFSFileHandles.get(fileID);
     try {
       let writable = await fileHandle.createWritable({keepExistingData: true});
@@ -463,7 +461,7 @@ addToLibrary({
 
   _wasmfs_opfs_flush_access__deps: ['$wasmfsOPFSAccessHandles', '$wasmfsOPFSProxyFinish'],
   _wasmfs_opfs_flush_access__async: {{{ !PTHREADS }}},
-  _wasmfs_opfs_flush_access: async function(ctx, accessID, errPtr) {
+  _wasmfs_opfs_flush_access: async (ctx, accessID, errPtr) => {
     let accessHandle = wasmfsOPFSAccessHandles.get(accessID);
     try {
       await accessHandle.flush();
