@@ -22,12 +22,12 @@ void* start_pthread(void* arg) {
 }
 
 #define CHECK(X, EXPECTED) rtn = X; if (rtn != EXPECTED) printf(#X " returned %s\n", strerror(rtn)); assert(rtn == EXPECTED)
-#define CHECK_FAIL(X) CHECK(X, EAGAIN)
+#define CHECK_FAIL(X) CHECK(X, ENOTSUP)
 #define CHECK_SUCCESS(X) CHECK(X, 0)
 
 #define CHECK_C11(X, expected) rtn = X; if (rtn != expected) printf(#X " returned %d\n", rtn); assert(rtn == expected)
 #define CHECK_C11_SUCCESS(X) CHECK_C11(X, thrd_success)
-#define CHECK_C11_FAIL(X) CHECK_C11(X, thrd_nomem)
+#define CHECK_C11_FAIL(X) CHECK_C11(X, thrd_error)
 
 void test_c11_threads() {
   printf("test_c11_threads\n");
