@@ -18,7 +18,7 @@ from common import (
   read_file,
   test_file,
 )
-from decorators import node_pthreads, parameterized
+from decorators import parameterized, requires_pthreads
 
 from tools import building, shared
 
@@ -265,7 +265,7 @@ class codesize(RunnerCore):
 
     if '-sSINGLE_FILE' not in cflags:
       # measure the wasm size without the name section
-      building.strip('a.out.wasm', 'a.out.nodebug.wasm', sections=['name'])
+      building.strip_sections('a.out.wasm', 'a.out.nodebug.wasm', ['name'])
       outputs.append('a.out.nodebug.wasm')
 
       imports, exports, funcs = self.parse_wasm('a.out.wasm')
@@ -319,7 +319,7 @@ class codesize(RunnerCore):
     self.cflags.append('--no-entry')
     self.run_codesize_test('minimal.c', args, check_full_js=check_full_js)
 
-  @node_pthreads
+  @requires_pthreads
   @parameterized({
     '': ([],),
     'memgrowth': (['-sALLOW_MEMORY_GROWTH'],),
