@@ -41,6 +41,8 @@ CLANG_FLAGS_WITH_ARGS = {
 # default set.
 EXTRA_INCOMING_JS_API = [
   'fetchSettings',
+  'logReadFiles',
+  'loadSplitModule',
 ]
 
 logger = logging.getLogger('args')
@@ -105,7 +107,7 @@ class EmccOptions:
   s_args: list[str] = []
   save_temps = False
   shared = False
-  shell_path = None
+  shell_html = None
   source_map_base = ''
   syntax_only = False
   target = ''
@@ -446,7 +448,7 @@ def parse_args(newargs):  # noqa: C901, PLR0912, PLR0915
     elif arg == '-###':
       shared.SKIP_SUBPROCS = True
     elif check_arg('--shell-file'):
-      options.shell_path = consume_arg_file()
+      options.shell_html = consume_arg_file()
     elif check_arg('--source-map-base'):
       options.source_map_base = consume_arg()
     elif check_arg('--emit-tsd'):
@@ -508,7 +510,6 @@ def parse_args(newargs):  # noqa: C901, PLR0912, PLR0915
     elif arg == '-fno-exceptions':
       settings.DISABLE_EXCEPTION_CATCHING = 1
       settings.DISABLE_EXCEPTION_THROWING = 1
-      settings.WASM_EXCEPTIONS = 0
     elif arg == '-mbulk-memory':
       feature_matrix.enable_feature(feature_matrix.Feature.BULK_MEMORY,
                                     '-mbulk-memory',
@@ -521,7 +522,7 @@ def parse_args(newargs):  # noqa: C901, PLR0912, PLR0915
                                     override=True)
     elif arg == '-mno-sign-ext':
       feature_matrix.disable_feature(feature_matrix.Feature.SIGN_EXT)
-    elif arg == '-mnontrappting-fptoint':
+    elif arg == '-mnontrapping-fptoint':
       feature_matrix.enable_feature(feature_matrix.Feature.NON_TRAPPING_FPTOINT,
                                     '-mnontrapping-fptoint',
                                     override=True)
@@ -792,10 +793,6 @@ def apply_user_settings():
       # used for warnings in emscripten.py
       settings.USER_EXPORTS = settings.EXPORTED_FUNCTIONS.copy()
 
-    # TODO(sbc): Remove this legacy way.
-    if key == 'WASM_OBJECT_FILES':
-      settings.LTO = 0 if value else 'full'
-
     if key == 'JSPI':
       settings.ASYNCIFY = 2
     if key == 'JSPI_IMPORTS':
